<?php
/**
 * Minta controller a Webgalamb REST api-hoz
 *
 * A lekérdezéseknél a $params tömbben használható paraméterekről bővebb infó: 
 * https://www.webgalamb.hu/wg8sugo/?page=rest-api
 *
 * Copyright: E.N.S. Zrt. 2020 <kapcsolat@webgalamb.hu>
 */

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use GuzzleHttp\Client;

class WGapiController extends Controller
{
	protected $api_url = 'http://webgalamb.ens.hu/wg8/rapi.php';
	protected $token = 'c70a130806cee7b8';
	protected $secret = '0c46d1ba4e12c40b20a3fdf01bfa87295e2ad55149ab';
	protected $stamp;
	protected $sig;
	
	public function __construct()
	{
		$this->stamp = date('c');
		$this->sig = hash_hmac('SHA256', $this->stamp, $this->secret);		
		$this->client = new Client(['base_uri' => $this->api_url]);
	}
	


    /**
     * Új feliratkozók azonosítóinak lekérdezése
     *
     * @param  array  $params
     * @return array
     */
	public function GetNewSubscribers($params)
	{
		return $this->get("GetNewSubscribers", $params);
	}

    /**
     * Módosult feliratkozók azonosítóinak lekérdezése
     *
     * @param  array  $params
     * @return array
     */
	public function GetUpdatedSubscribers($params)
	{
		return $this->get('GetUpdatedSubscribers', $params);
	}

    /**
     * Egy adott csoport feliratkozók azonosítóinak lekérdezése
     *
     * @param  array  $params
     * @return array
     */
	public function GetGroupUserIDs($params)
	{
		return $this->get('GetGroupUserIDs', $params);
	}

    /**
     * Egy adott e-mail címhez tartozó azonosítók lekérdezése
     *
     * @param  array  $params
     * @return array
     */
	public function GetUserIDs($params)
	{
		return $this->get('GetUserIDs', $params);
	}

    /**
     * Feliratkozó adatainak lekérdezése
     *
     * @param  array  $params
     * @return array
     */
	public function GetSubscriber($params)
	{
		return $this->get('GetSubscriber', $params);
	}

    /**
     * Csoportok lekérdezése
     *
     * @return array
     */
	public function GetGroups()
	{
		return $this->get('GetGroups');
	}

    /**
     * Új feliratkozó felvitele
     *
     * @param  array  $params
     * @return array
     */
	public function InsertSubscriber($params)
	{
		return $this->post('InsertSubscriber', $params);
	}

    /**
     * Feliratkozó adatainak módosítása
     *
     * @param  array  $params
     * @return array
     */
	public function EditSubscriber($params)
	{
		return $this->post('EditSubscriber', $params);
	}

    /**
     * Feliratkozó másolása
     *
     * @param  array  $params
     * @return array
     */
	public function CopySubscriber($params)
	{
		return $this->post('CopySubscriber', $params);
	}

    /**
     * Feliratkozó törlése
     *
     * @param  array  $params
     * @return array
     */
	public function DeleteSubscriber($params)
	{
		return $this->post('DeleteSubscriber', $params);
	}








	/**
	 *
	 * alapvető függvények
	 *
	 */
	public function response()
	{
		if($this->response->getStatusCode() != 200) {
			return [
				'error' => 'API kommunikációs hiba',
				'status_code' => $this->response->getStatusCode()
			];
		}
		
		if($this->response->getHeader('content-type')[0] == 'application/json; charset=utf-8') {
			return json_decode($this->response->getBody()->getContents(), 1);
		}
		
        return $this->response->getBody()->getContents();
	}
	
	public function get($query, $params=[])
	{
		$query = '?request='.$query.'/'.http_build_query(['parameters'=>json_encode($params)]);		
		$this->response = $this->client->get($query, [
			'headers' => [
				'X-Auth-Token' => $this->token,
				'X-Auth-Signature' => $this->sig,
				'X-Auth-Timestamp' => $this->stamp,
			],
			'format' => "json", 
			'debug' => false, 
			'exceptions' => false 
		]);
		
		return $this->response();
	}
	
	public function post($query, $params)
	{
		$query = '?request='.$query.'/';
		$this->response = $this->client->post($query, [
			'headers' => [ 
				'X-Auth-Token' => $this->token,
				'X-Auth-Signature' => $this->sig,
				'X-Auth-Timestamp' => $this->stamp,
			], 
			'debug' => false, 
			'exceptions' => false,
			'form_params' => [ 'parameters' => json_encode($params) ]
		]);
		
		return $this->response();
	}
}
